Package: R.ComDim
Type: Package
Title: Common Dimensions (ComDim) Multi-Block Analysis
Version: 1.0.0
Authors@R: person(given = "Francesc",
                  family = "Puig-Castellví",
                  role = c("aut", "cre"),
                  email = "puig.francesc@gmail.com")
Description: 
    Common Dimensions (ComDim) is a multi-block method that simultaneously
    considers multiple data tables to find latent components that are common
    to all the tables as well as those specific to each data table, along
    with the contribution of each table to each component.
    See Jouan-Rimbaud Bouveresse and Rutledge (2024)
    <doi:10.1002/cem.3454>, Boccard and Rutledge (2013)
    <doi:10.1016/j.aca.2013.01.022>, and Puig-Castellví et al. (2021)
    <doi:10.1016/j.chemolab.2021.104422>.
License: MIT + file LICENSE
Depends: methods
Imports: pracma, utils, ggplot2, ConsensusOPLS
Suggests: gridExtra, imputeLCMD, ica, MultiAssayExperiment,
        SummarizedExperiment, ropls
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Collate: 'R.ComDim-package.R' 'ComDim-classes.R' 'AddMetadata.R'
        'ComDim_Exploratory.R' 'ComDim_PCA.R' 'ComDim_PLS.R'
        'ComDim_OPLS.R' 'ComDim_y.R' 'ExpandMultiBlock.R'
        'FilterSamplesMultiBlock.R' 'NAInfRemoveMultiBlock.R'
        'MakeComDimLoadingsTable.R' 'MakeComDimScoresTable.R'
        'MultiAssayExperiment2MultiBlock.R' 'MultiBlock.R'
        'MultiBlock2MultiAssayExperiment.R' 'MultiBlock2Matrix.R'
        'NormalizeMultiBlock.R' 'PredictMultiBlock.R'
        'ProcessMultiBlock.R' 'SelectFeaturesRW.R'
        'SimulateMultiBlock.R' 'SplitRW.R'
        'SummarizedExperiment2MultiBlock.R'
        'data-KEGG_table_metabolites.R' 'data-RNAseq3.R' 'data-extra.R'
        'data-gcms.R' 'data-intra.R' 'data-lcms.R' 'data-lipids.R'
        'data-metadata_RNAseq3.R' 'data-metadata_lipids.R'
        'data-mirnaseq.R' 'data-rnaseq.R'
NeedsCompilation: no
Packaged: 2026-05-08 14:28:08 UTC; Xisco
Author: Francesc Puig-Castellví [aut, cre]
Maintainer: Francesc Puig-Castellví <puig.francesc@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-13 07:40:07 UTC
Built: R 4.5.2; ; 2026-05-13 09:56:45 UTC; unix
