# Generated by roxygen2: do not edit by hand

export("blockNames<-")
export("sampleNames<-")
export("variableNames<-")
export(AddMetadata)
export(ComDim_Exploratory)
export(ComDim_OPLS)
export(ComDim_PCA)
export(ComDim_PLS)
export(ComDim_y)
export(ExpandMultiBlock)
export(FilterSamplesMultiBlock)
export(MakeComDimLoadingsTable)
export(MakeComDimScoresTable)
export(MultiAssayExperiment2MultiBlock)
export(MultiBlock)
export(MultiBlock2Matrix)
export(MultiBlock2MultiAssayExperiment)
export(NAInfRemoveMultiBlock)
export(NormalizeMultiBlock)
export(OPLS_NIPALS_DNR)
export(PredictMultiBlock)
export(ProcessMultiBlock)
export(SelectFeaturesRW)
export(SimulateMultiBlock)
export(SplitRW)
export(SummarizedExperiment2MultiBlock)
export(blockNames)
export(sampleNames)
export(variableNames)
exportMethods("blockNames<-")
exportMethods("sampleNames<-")
exportMethods("variableNames<-")
exportMethods(blockNames)
exportMethods(ncol)
exportMethods(nrow)
exportMethods(sampleNames)
exportMethods(variableNames)
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,validObject)
importFrom(stats,median)
importFrom(stats,qnorm)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,globalVariables)
