#' miRNAseq data on cell differentiation
#'
#'
#' @name mirnaseq
#'
#' @docType data
#'
#' @usage data(dataset3)
#'
#' @keywords dataset
#'
#' @author  Cabrero et al. (2019) Scientific data 6:256
#' (\doi{10.1038/s41597-019-0202-7})
#'
#' @source \href{https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE75394}{NCBI}
#'
#' @examples
#' data(dataset3)
#' #' mb_d3 <- MultiBlock(Data = list(mirnaseq = mirnaseq))
"mirnaseq"
