#' Metadata for the metabolites in growth medium
#'
#'
#' @name KEGG_table_metabolites
#'
#' @docType data
#'
#' @usage data(mouse_ds)
#'
#' @keywords dataset
#'
#' @author  Radic Shechter et al. (2021) Molecular Systems Biology 17:e10141
#' (\doi{10.15252/msb.202010141})
#'
#' @source \doi{10.15252/msb.202010141}
#'
#' @examples
#' data(mouse_ds)
#' #' intraMB <- ExpandMB(data = intra, metadata = KEGG_table_metabolites,
#' #'   minblock = 10, loquace = FALSE)
"KEGG_table_metabolites"
