#' Intracellular metabolites in growth medium
#'
#'
#' @name intra
#'
#' @docType data
#'
#' @usage data(mouse_ds)
#'
#' @keywords dataset
#'
#' @author  Radic Shechter et al. (2021) Molecular Systems Biology 17:e10141
#' (\doi{10.15252/msb.202010141})
#'
#' @source \doi{10.15252/msb.202010141}
#'
#' @examples
#' data(mouse_ds)
#' # MB <- MultiBlock(Data = list(RNAseq3 = RNAseq3,
#' #   lipids = lipids, intra = intra, extra = extra))
"intra"
