% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ComDim-classes.R
\name{blockNames<-}
\alias{blockNames<-}
\alias{blockNames<-,MultiBlock-method}
\title{blockNames<-}
\usage{
blockNames(x) <- value

\S4method{blockNames}{MultiBlock}(x) <- value
}
\arguments{
\item{x}{A MultiBlock object.}

\item{value}{A character vector of new block names (same length as the
number of blocks).}
}
\value{
The updated MultiBlock object.
}
\description{
Set the block names of a MultiBlock object.
Renames the Data and Variables slots, and updates Batch and Metadata
names to stay consistent.
}
\examples{
b1 <- matrix(rnorm(500), 10, 50)
b2 <- matrix(rnorm(800), 10, 80)
mb <- MultiBlock(Data = list(b1 = b1, b2 = b2))
blockNames(mb) <- c("block1", "block2")
blockNames(mb) # c("block1", "block2")
}
