% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ComDim-classes.R
\name{nrow,MultiBlock-method}
\alias{nrow,MultiBlock-method}
\title{nrow for MultiBlock}
\usage{
\S4method{nrow}{MultiBlock}(x)
}
\arguments{
\item{x}{A MultiBlock object.}
}
\value{
A named integer vector with the number of rows per block.
}
\description{
Return the number of rows (samples) in each block of a MultiBlock.
For a valid MultiBlock all blocks share the same number of rows, so the
result is a named integer vector with one (identical) value per block.
}
\examples{
b1 <- matrix(rnorm(500), 10, 50)
b2 <- matrix(rnorm(800), 10, 80)
mb <- MultiBlock(Data = list(b1 = b1, b2 = b2))
nrow(mb) # c(b1 = 10, b2 = 10)
}
